@@ -1,7 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: UTF8 -*-
 
-import pygtk
 import gtk
 import gtk.gdk
 import hildon
@@ -11,9 +10,24 @@ import string
 
 from molmass import MassCalc, SanityError
 
-osso_c = osso.Context("maemo_periodic", "1.1", False)
+osso_c = osso.Context("maemo_periodic", "1.2", False)
+
+distro = 'fremantle'
+
+#detect if is ran locally or not
+import sys
+runningpath = sys.path[0]
+
+if '/usr/share' in runningpath:
+    running_locally = False
+else:
+    running_locally = True
+
+if running_locally:
+    imgdir = 'pixmaps/'
+else:
+    imgdir = '/usr/share/maemo-periodic/pixmaps/'
 
-distro = 'chinook'
 
 #grupos clasicos
 c1=[3,11,19,37,55,87] #Alcalinos
@@ -31,7 +45,7 @@ c9=range(89,104) #Actinidos
 
 #grupos de elementos
 g1=[1,3,11,19,37,55,87,29,47,79,111,65,97]
-g2=[4,12,20,38,56,88,30,48,80,66,98]
+g2=[4,12,20,38,56,88,30,48,80,66,98,112]
 g3=[5,13,31,49,81,67,99,21,39,57,89]
 g4=[6,14,32,50,82,68,100,22,40,72,104,58,90]
 g5=[7,15,33,51,83,69,101,23,41,73,105,59,91]
@@ -46,7 +60,6 @@ tref=298.0
 
 from listas import *
 
-
 def elige_color(tipo,num):
 
 	if tipo==1: #Por grupos
@@ -85,35 +98,243 @@ def elige_color(tipo,num):
 				fusion=float(aux[0])
 			except:
 				fusion=-1
-			
+
 		if tref<fusion: return "#D0BB87"
 		elif tref<vapor: return 'cyan'
 		elif (fusion>0 and vapor>0): return 'grey'
 		else: return 'magenta'
-			
+
 	else: return 'grey'
 
 
 
 
 class MainWindow(hildon.Program):
-	
+
 
 	def __init__(self):
 		hildon.Program.__init__(self)
-        
-		self.window = hildon.Window()
+
+		if distro == 'fremantle':
+			self.window = hildon.StackableWindow()
+		else:
+			self.window = hildon.Window()
+
 		self.window.set_default_size(800, 480)
 		self.window.set_title('Periodic Table')
 		self.window.connect("destroy", gtk.main_quit)
 
 		self.window.connect("key-press-event", self.on_key_press)
 		self.window.connect("window-state-event", self.on_window_state_change)
-		self.window_in_fullscreen = False 
+		self.window_in_fullscreen = False
 
 		self.add_window(self.window)
- 
-## Make menu       
+
+
+		if distro == 'fremantle':
+			self.make_fremantle_menu()
+		else:
+			self.make_old_menu()
+
+		if distro == 'fremantle':
+			pannable = hildon.PannableArea()
+			pannable.set_property("force", 10)
+			pannable.set_property("mov-mode", hildon.MOVEMENT_MODE_BOTH)
+
+## Make table
+
+		self.table1 = gtk.Table()
+		self.table1.show()
+		self.table1.set_row_spacings(0)
+		self.table1.set_col_spacings(0)
+
+
+
+		boton=['']
+		global caja
+		caja=['']
+		for i in range(1,len(nom)):
+			if distro == 'chinook' or distro == 'fremantle':
+				pass
+			else:
+				self.alignment1 = gtk.Alignment(0.5, 0.5, 1, 1)
+				self.alignment1.show()
+
+				self.hbuttonbox1 = gtk.HButtonBox()
+				self.hbuttonbox1.set_size_request(37, 20)
+				self.hbuttonbox1.show()
+				self.hbuttonbox1.set_spacing(0)
+				self.hbuttonbox1.set_layout(gtk.BUTTONBOX_EDGE)
+
+			self.button1 = hildon.Button(gtk.HILDON_SIZE_AUTO_WIDTH,
+							hildon.BUTTON_ARRANGEMENT_HORIZONTAL)
+			boton.append(self.button1)
+
+			if distro == 'fremantle':
+				boton[i].set_size_request(80, 20)
+			else:
+				boton[i].set_size_request(38, 20)
+
+			boton[i].set_border_width(0)
+			boton[i].connect("clicked", self.on_click)
+
+			self.eventbox=gtk.EventBox()
+			self.eventbox.set_size_request(15, 20)
+			caja.append(self.eventbox)
+
+			boton[i].add(self.eventbox)
+
+			self.eventbox.show()
+			self.label1 = gtk.Label()
+			self.label1.set_markup("<small>"+sim[i]+"</small>")
+			self.eventbox.add(self.label1)
+			self.label1.show()
+			color=elige_color(2,i)
+			self.eventbox.modify_bg(gtk.STATE_NORMAL,self.eventbox.get_colormap().alloc_color(color))
+
+
+			boton[i].set_name(sim[i])
+			boton[i].show()
+			if distro == 'chinook' or distro == 'fremantle':
+				pass
+			else:
+				self.hbuttonbox1.pack_start(boton[i], False, False, 0)
+				self.alignment1.add(self.hbuttonbox1)
+
+			if i==1:
+				left=0
+				top=0
+			elif i==2:
+				left=17
+				top=0
+			elif i in range(3,5):
+				left=i-3
+				top=1
+			elif i in range(5,11):
+				left=i+7
+				top=1
+			elif i in range(11,13):
+				left=i-11
+				top=2
+			elif i in range(13,19):
+				left=i-1
+				top=2
+			elif i in range(19,37):
+				left=i-19
+				top=3
+			elif i in range(37,55):
+				left=i-37
+				top=4
+			elif i in range(55,57):
+				left=i-55
+				top=5
+			elif i in range(72,87):
+				left=i-69
+				top=5
+			elif i in range(87,89):
+				left=i-87
+				top=6
+			elif i in range(104,113):
+				left=i-101
+				top=6
+			elif i in range(57,72):
+				left=i-55
+				top=7
+			elif i in range(89,104):
+				left=i-87
+				top=8
+
+
+
+			right=left+1
+			bottom=top+1
+			if distro == 'chinook' or distro == 'fremantle':
+				self.table1.attach(boton[i], left, right, top, bottom, gtk.EXPAND|gtk.FILL, gtk.EXPAND|gtk.FILL, 0, 0)
+			else:
+				self.table1.attach(self.alignment1, left, right, top, bottom, gtk.EXPAND|gtk.FILL, gtk.EXPAND|gtk.FILL, 0, 0)
+
+## add table to main window
+
+
+		if distro == 'fremantle':
+			pannable.add_with_viewport(self.table1)
+			self.window.add(pannable)
+		else:
+			self.window.add(self.table1)
+
+	def color_selector(self):
+		selector = hildon.hildon_touch_selector_new_text()
+		data = ["Classic", "Colorless", "Groups", "Phys. State"]
+		for i in range(len(data)):
+			selector.append_text(data[i])
+
+		return selector
+
+	def on_set_color(self, button):
+		dlg = hildon.PickerDialog(self.window)
+		selector = self.color_selector()
+		selector.connect("changed" , self.set_color, dlg, button)
+		dlg.set_selector(selector)
+
+		dlg.show_all()
+		dlg.run()
+
+	def set_color(self, selector, column, dlg, button):
+		value = selector.get_current_text()
+		dlg.destroy()
+		if value == 'Classic':
+			self.on_view_classic(button)
+		elif value == 'Colorless':
+			self.on_view_cless(button)
+		elif value == 'Groups':
+			self.on_view_group(button)
+		elif value == 'Phys. State':
+			self.on_view_fisest(button)
+		button.set_value(value)
+
+
+	def make_fremantle_menu(self):
+		menu = hildon.AppMenu()
+		self.window.set_app_menu(menu)
+
+
+		col_menu = hildon.Button(hildon.SIZE_REQUEST_MINIMUM, hildon.BUTTON_ARRANGEMENT_HORIZONTAL)
+		col_menu.set_value('Classic')
+		col_menu.set_title('View')
+
+
+		about_menu = gtk.Button("About")
+		opt_menu = gtk.Button("Options")
+		graph_menu = gtk.Button("Graphics")
+		calc_menu = gtk.Button("Mass calc")
+		ref_menu = gtk.Button("References")
+		conn_menu = gtk.Button("Connect To...")
+		query_menu = gtk.Button("Query...")
+
+		col_menu.connect("clicked", self.on_set_color)
+		opt_menu.connect("clicked", self.on_options)
+		about_menu.connect("clicked", self.on_about_credits)
+		graph_menu.connect("clicked", self.on_grafics)
+		calc_menu.connect("clicked", self.on_calc)
+		ref_menu.connect("clicked", self.on_about_refs)
+		conn_menu.connect("clicked", self.on_web_conect)
+		query_menu.connect("clicked", self.on_web_query)
+
+		menu.append(col_menu)
+		menu.append(opt_menu)
+		menu.append(graph_menu)
+		menu.append(calc_menu)
+		menu.append(query_menu)
+		menu.append(conn_menu)
+		menu.append(about_menu)
+		menu.append(ref_menu)
+
+		menu.show_all()
+
+
+
+	def make_old_menu(self):
+## Make menu
 		self.menubar1 = gtk.Menu()
 		for child in self.menubar1.get_children():
 			child.reparent(menu)
@@ -133,7 +354,7 @@ class MainWindow(hildon.Program):
 		self.ver.set_size_request(-1, 45)
 		self.ver.show()
 		self.ver.set_submenu(self.m_view)
-		
+
 		self.sincol=gtk.MenuItem("Colorless")
 		self.sincol.set_size_request(-1, 45)
 		self.sincol.show()
@@ -172,7 +393,7 @@ class MainWindow(hildon.Program):
 		self.grafics.set_size_request(-1, 45)
 		self.grafics.show()
 		self.grafics.connect("activate", self.on_grafics)
-		
+
 #Submenu Calc
 
 		self.calc=gtk.MenuItem("Calc")
@@ -222,10 +443,10 @@ class MainWindow(hildon.Program):
 
 		self.m_about.append(self.refs)
 		self.m_about.append(self.credits)
-		
+
 
 #Empaquetar elementos del menu
-		
+
 		self.menubar1.append(self.options)
 		self.menubar1.append(self.ver)
 		self.menubar1.append(self.grafics)
@@ -233,117 +454,9 @@ class MainWindow(hildon.Program):
 		self.menubar1.append(self.web)
 		self.menubar1.append(self.about)
 		self.menubar1.append(self.exit)
-		
-
-## Make table
-
-		self.table1 = gtk.Table()
-		self.table1.show()
-		self.table1.set_row_spacings(0)
-		self.table1.set_col_spacings(0)
 
 
 
-		boton=['']
-		global caja
-		caja=['']
-		for i in range(1,len(nom)):
-			if distro == 'chinook':
-				pass
-			else:
-				self.alignment1 = gtk.Alignment(0.5, 0.5, 1, 1)
-				self.alignment1.show()
-
-				self.hbuttonbox1 = gtk.HButtonBox()
-				self.hbuttonbox1.set_size_request(37, 20)
-				self.hbuttonbox1.show()
-				self.hbuttonbox1.set_spacing(0)
-				self.hbuttonbox1.set_layout(gtk.BUTTONBOX_EDGE)
-
-			self.button1 = gtk.Button()
-			boton.append(self.button1)
-
-			boton[i].set_size_request(38, 20)
-			boton[i].set_border_width(0)
-			boton[i].connect("clicked", self.on_click)
-
-			self.eventbox=gtk.EventBox()
-			self.eventbox.set_size_request(38, 20)
-			caja.append(self.eventbox)
-			boton[i].add(self.eventbox)
-			self.eventbox.show()
-			self.label1 = gtk.Label()
-			self.label1.set_markup("<small>"+sim[i]+"</small>")
-			self.eventbox.add(self.label1)
-			self.label1.show()
-			color=elige_color(2,i)
-			self.eventbox.modify_bg(gtk.STATE_NORMAL,self.eventbox.get_colormap().alloc_color(color))
-                       
-
-			boton[i].set_name(sim[i])
-			boton[i].show()
-			if distro == 'chinook':
-				pass
-			else:
-				self.hbuttonbox1.pack_start(boton[i], False, False, 0)
-				self.alignment1.add(self.hbuttonbox1)
-
-			if i==1:
-				left=0
-				top=0
-			elif i==2:
-				left=17
-				top=0
-			elif i in range(3,5):
-				left=i-3
-				top=1
-			elif i in range(5,11):
-				left=i+7
-				top=1
-			elif i in range(11,13):
-				left=i-11
-				top=2
-			elif i in range(13,19):
-				left=i-1
-				top=2
-			elif i in range(19,37):
-				left=i-19
-				top=3
-			elif i in range(37,55):
-				left=i-37
-				top=4
-			elif i in range(55,57):
-				left=i-55
-				top=5
-			elif i in range(72,87):
-				left=i-69
-				top=5
-			elif i in range(87,89):
-				left=i-87
-				top=6
-			elif i in range(104,112):
-				left=i-101
-				top=6
-			elif i in range(57,72):
-				left=i-55
-				top=7
-			elif i in range(89,104):
-				left=i-87
-				top=8
-			
-			
-
-			right=left+1
-			bottom=top+1
-			if distro == 'chinook':
-				self.table1.attach(boton[i], left, right, top, bottom, gtk.EXPAND|gtk.FILL, gtk.EXPAND|gtk.FILL, 0, 0)
-			else:
-				self.table1.attach(self.alignment1, left, right, top, bottom, gtk.EXPAND|gtk.FILL, gtk.EXPAND|gtk.FILL, 0, 0)
-
-## add table to main window
-
-		self.window.add(self.table1)
-
 ## Functions for call elements window
 
 	def on_click(self, widget):
@@ -354,13 +467,13 @@ class MainWindow(hildon.Program):
 
 
 ## Functions for fullscreen
-	def on_window_state_change(self, widget, event, *args):           
+	def on_window_state_change(self, widget, event, *args):
 		if event.new_window_state & gtk.gdk.WINDOW_STATE_FULLSCREEN:
 			self.window_in_fullscreen = True
 		else:
 			self.window_in_fullscreen = False
 
-	def on_key_press(self, widget, event, *args):            
+	def on_key_press(self, widget, event, *args):
 		if event.keyval == gtk.keysyms.F6:
 			if self.window_in_fullscreen:
 				self.window.unfullscreen ()
@@ -376,7 +489,7 @@ class MainWindow(hildon.Program):
 		for i in range(1,len(caja)):
 			caja[i].modify_bg(gtk.STATE_NORMAL,caja[i].get_colormap().alloc_color("grey"))
 			caja[i].show()
-			
+
 
 	def on_view_group(self, widget):
 		for i in range(1,len(caja)):
@@ -391,12 +504,12 @@ class MainWindow(hildon.Program):
 			caja[i].show()
 
 	def on_view_fisest(self,widget):
-	
+
 		for i in range(1,len(caja)):
 			color=elige_color(3,i)
 			caja[i].modify_bg(gtk.STATE_NORMAL,caja[i].get_colormap().alloc_color(color))
 			caja[i].show()
-	
+
 
 	def on_options(self,widget):
 		Opciones()
@@ -428,12 +541,12 @@ class AboutDialog:
 
 		dialog = gtk.AboutDialog()
 		dialog.set_name("Maemo Periodic")
-		dialog.set_version("1.0")
-		dialog.set_copyright("Copyleft © 2006")
+		dialog.set_version("1.2")
+		dialog.set_copyright("Copyright © 2006-2009")
 		dialog.set_website("https://garage.maemo.org/projects/maemo-periodic/")
 		dialog.set_authors(["Luis Lorenzo Paris <llorenzo@gmail.com>", "Daniel Martín Yerga <dyerga@gmail.com>","","Module molmass written for Patrick Thomson <patrick.thomson@gmail.com>"])
 		dialog.set_artists(["Logo and icon by Daniel Martín Yerga <dyerga@gmail.com>."])
- 		logo = gtk.gdk.pixbuf_new_from_file("/usr/share/maemo-periodic/pixmaps/about.png")
+ 		logo = gtk.gdk.pixbuf_new_from_file(imgdir+"about.png")
 		dialog.set_logo(logo)
 		dialog.set_license("This program is released under the GNU General Public License.\nPlease visit http://www.gnu.org/copyleft/gpl.html for details.")
 		dialog.run()
@@ -447,6 +560,9 @@ class MyDialog(MainWindow):
 #En la ventana caben 54 caracteres
 
 	def __init__(MainWindow):
+		def show_tab(widget, notebook, number):
+			notebook.set_current_page(number)
+
 		def scroll_to(x=0, y=0):
 			v = swin.get_vadjustment()
 			child_height = swin.child.child.size_request()[1]
@@ -462,7 +578,7 @@ class MyDialog(MainWindow):
 
 # Los valores de 100 y -100 son los 'pixels' que avanza el scroll
 
-		def on_key_press(widget, event, *args):            
+		def on_key_press(widget, event, *args):
 			if event.keyval == gtk.keysyms.Down:
 				scroll_by(0, 100)
 			elif event.keyval == gtk.keysyms.Up:
@@ -472,31 +588,37 @@ class MyDialog(MainWindow):
 					win.unfullscreen ()
 				else:
 					win.fullscreen ()
-    
-		def on_window_state_change(widget, event, *args):           
+
+		def on_window_state_change(widget, event, *args):
 			if event.new_window_state & gtk.gdk.WINDOW_STATE_FULLSCREEN:
 				win.win_in_fullscreen = True
 			else:
 				win.win_in_fullscreen = False
 
-
-		win = hildon.Window()
+		if distro == 'fremantle':
+			win = hildon.StackableWindow()
+		else:
+			win = hildon.Window()
 		win.connect('destroy', gtk.Widget.destroy)
 		win.connect("key-press-event", on_key_press)
 		win.connect("window-state-event", on_window_state_change)
-		win.win_in_fullscreen = False 
+		win.win_in_fullscreen = False
 		nelem=sim.index(element)
 		win.set_title(nom[nelem])
 
 		notebook = gtk.Notebook()
-		notebook.set_tab_pos(gtk.POS_BOTTOM)
+		notebook.set_show_tabs(False)
 		notebook.set_scrollable(False)
 		notebook.show()
 
-		swin = gtk.ScrolledWindow()
-		if distro == 'chinook':
-			hildon.hildon_helper_set_thumb_scrollbar(swin, True)
-		swin.set_policy(gtk.POLICY_NEVER, gtk.POLICY_AUTOMATIC)
+		if distro == 'fremantle':
+			swin = hildon.PannableArea()
+		else:
+			swin = gtk.ScrolledWindow()
+			swin.set_policy(gtk.POLICY_NEVER, gtk.POLICY_AUTOMATIC)
+			if distro == 'chinook':
+				hildon.hildon_helper_set_thumb_scrollbar(swin, True)
+
 #		win.add(swin)
 		swin.show()
 
@@ -505,24 +627,23 @@ class MyDialog(MainWindow):
 
 
 		for i in range(len(titulo)):
-		
+
 			tit=titulo[i]
-		
+
 			if props[i][nelem] in [' ','-'] or len(props[i][nelem])<1:
-		
-				etiqueta+="<b><u>%25s:</u></b> Na\n" % tit	
+				etiqueta+="<b>%25s:</b> Na\n" % tit
 			else:
-		
+
 				if corresp[i]>=0: unids=units[corresp[i]]
 				else:	unids=''
 				#si tiene unidades no sera muy largo: no se considea sumar len(unids)+1
-				if len(props[i][nelem])<23: etiqueta+="<b><u>%25s:</u></b> %s %s\n" % (tit,props[i][nelem],unids)
+				if len(props[i][nelem])<23: etiqueta+="<b>%25s:</b> %s %s\n" % (tit,props[i][nelem],unids)
 				else:
 					trozo=[]
 					resto=props[i][nelem]
 					corte=22
 					longitud=len(resto)-resto.count('>')*5.5
-				
+
 					while longitud>22:
 						while not resto[corte]==' ': corte-=1
 						corte+=1
@@ -531,17 +652,17 @@ class MyDialog(MainWindow):
 						longitud=len(resto)-resto.count('>')*5.5
 						corte=22
 					trozo.append(resto)
-					etiqueta+="<b><u>%25s:</u></b> %s\n" % (tit,trozo[0])
-					
+					etiqueta+="<b>%25s:</b> %s\n" % (tit,trozo[0])
+
 					for i in range(1,len(trozo)): etiqueta+=' '*26+trozo[i]+'\n'
 
 					#En este caso no hara falta poner unidades
 					#etiqueta+=' '*28+trozo[-1]+unids+'\n'
-				
-			
+
+
 		etiqueta+='</tt>'
-			
-		
+
+
 		label = gtk.Label(etiqueta)
 		label.set_use_markup(True)
 		label.set_line_wrap(False)
@@ -564,7 +685,7 @@ class MyDialog(MainWindow):
 		for i in range(len(isot_div)):
 			etiqueta01=str(isot_div[i])
 			etiqueta1+= "\n" +etiqueta01
-		
+
 		etiqueta1+='</tt>'
 		label2 = gtk.Label(etiqueta1)
 		label2.set_use_markup(True)
@@ -582,9 +703,33 @@ class MyDialog(MainWindow):
 
 		notebook.append_page(scrolledwindow2, label55)
 
-		win.add(notebook)
-		win.show()
-		
+		vbox = gtk.VBox()
+
+		hbox = gtk.HBox()
+
+		if distro == 'fremantle':
+			button1 = hildon.Button(gtk.HILDON_SIZE_FINGER_HEIGHT,
+									hildon.BUTTON_ARRANGEMENT_HORIZONTAL)
+			button2 = hildon.Button(gtk.HILDON_SIZE_FINGER_HEIGHT,
+									hildon.BUTTON_ARRANGEMENT_HORIZONTAL)
+			button1.set_title("Properties")
+			button2.set_title("Isotopes")
+		else:
+			button1 = gtk.Button("Properties")
+			button2 = gtk.Button("Isotopes")
+
+		button1.connect("clicked", show_tab, notebook, 0)
+		button2.connect("clicked", show_tab, notebook, 1)
+
+		hbox.pack_start(button1, True, True, 0)
+		hbox.pack_start(button2, True, True, 0)
+
+		vbox.pack_start(notebook, True, True, 0)
+		vbox.pack_start(hbox, False, False, 0)
+
+		win.add(vbox)
+		win.show_all()
+
 
 class MassMolecular(MainWindow):
 	def __init__(MainWindow):
@@ -625,10 +770,11 @@ class MassMolecular(MainWindow):
 		hbox = gtk.HBox(False, 8)
 		vbox1.pack_start(hbox)
 
-		entry1 = gtk.Entry()
-		entry1.set_text("")
-		entry1.set_editable(True)
-		entry1.set_visibility(True)
+		if distro == 'fremantle':
+			entry1 = hildon.Entry(gtk.HILDON_SIZE_FINGER_HEIGHT)
+		else:
+			entry1 = gtk.Entry()
+
 		vbox1.set_spacing(2)
 		hbox.pack_start(entry1, True, True, 0)
 
@@ -641,7 +787,12 @@ class MassMolecular(MainWindow):
 		vbox1.pack_start(hbox, True, True, 0)
 		vbox2 = gtk.VBox()
 
-		textview1 = gtk.TextView()
+
+		if distro == 'fremantle':
+			textview1 = hildon.TextView()
+		else:
+			textview1 = gtk.Entry()
+
 		textview1.set_wrap_mode(gtk.WRAP_NONE)
 		textview1.set_cursor_visible(False)
 		textview1.set_editable(False)
@@ -659,25 +810,32 @@ class MassMolecular(MainWindow):
 		hbuttonbox1.set_layout(gtk.BUTTONBOX_END)
 
 		button1 = gtk.Button(label="Calculate")
+		button1.set_size_request(150, 70)
 		button1.show()
 		button1.connect("clicked", on_calcular_clicked)
 		hbuttonbox1.pack_start(button1)
 
-		button2 = gtk.Button(label="Close")
-		button2.show()
-		button2.connect("clicked", on_cerrar_clicked)
-		hbuttonbox1.pack_start(button2)
+		if distro != 'fremantle':
+			button2 = gtk.Button(label="Close")
+			button2.show()
+			button2.connect("clicked", on_cerrar_clicked)
+			hbuttonbox1.pack_start(button2)
 
 		dlg.action_area.pack_start(hbuttonbox1, False, False, 8)
 		dlg.vbox.pack_start(vbox1, True, True, 8)
-		
+
 		dlg.show_all()
 
 class GraficProps(MainWindow):
 	def __init__(MainWindow):
 
 		def save_png(widget):
-			file_dialog = hildon.FileChooserDialog(wgraf, gtk.FILE_CHOOSER_ACTION_SAVE)
+			if distro == 'fremantle':
+				m = hildon.FileSystemModel()
+				file_dialog = hildon.FileChooserDialog(wgraf, gtk.FILE_CHOOSER_ACTION_SAVE, m)
+			else:
+				file_dialog = hildon.FileChooserDialog(wgraf, gtk.FILE_CHOOSER_ACTION_SAVE)
+
 			file_dialog.set_default_response(gtk.RESPONSE_OK)
 
 			response = file_dialog.run()
@@ -688,7 +846,7 @@ class GraficProps(MainWindow):
 				pix_buffer.save(file_dialog.get_filename(), "png")
 			file_dialog.destroy()
 
-				
+
 		def crea_pixmap(widget):
 			x, y, width, height = wgraf.get_allocation()
 
@@ -699,7 +857,7 @@ class GraficProps(MainWindow):
 		def refoco(widget,event):
 			 x , y, width, height = event.area
 			 widget.window.draw_drawable(widget.get_style().fg_gc[gtk.STATE_NORMAL],pixmap, x, y, x, y, width, height)
-			
+
 
 		def ver_activo(combo):
 			model = combo.get_model()
@@ -710,31 +868,41 @@ class GraficProps(MainWindow):
 
 
 		def on_dibujar_clicked(widget):
-			ox=100
-			fx=650
+			if distro == 'fremantle':
+				ox=140
+				fx=750
+			else:
+				ox=100
+				fx=650
 			oy=300
 			fy=50
-			
+
 			x, y, width, height = wgraf.get_allocation()
-			pixmap.draw_rectangle(dra1.get_style().white_gc,True, 0, 0, width, height)			
-			
+			pixmap.draw_rectangle(dra1.get_style().white_gc,True, 0, 0, width, height)
+
 			gc.set_foreground(blanco)
 			gc.set_background(blanco)
 			dibujo.draw_rectangle(gc,True,0,0,700,350)
-			
+
 			gc.line_width=1
 			gc.line_style=0
 
+			if distro == 'fremantle':
+				axe=abutton.get_value()
+				nat_ini=sim.index(bbutton.get_value())
+				nat_fin=sim.index(cbutton.get_value())
+			else:
+				axe=ver_activo(comboprop)
+				nat_ini=sim.index(ver_activo(combode))
+				nat_fin=sim.index(ver_activo(comboa))
 
-			axe=ver_activo(comboprop)
 			nprop=titulo.index(axe)
 			axe='Graph '+axe
 			wgraf.set_title(axe)
-			nat_ini=sim.index(ver_activo(combode))
-			nat_fin=sim.index(ver_activo(comboa))
+
 			gc.set_foreground(negro)
 			txto.set_text(titulo[nprop])
-		
+
 			pixmap.draw_layout(gc,250,15,txto)
 			gc.set_foreground(gris)
 			gc.set_background(blanco)
@@ -751,42 +919,42 @@ class GraficProps(MainWindow):
 					valores.append(aux)
 					if aux>maxy: maxy=aux
 					if aux<miny: miny=aux
-						
-				
+
+
 				except:
 					try:
 						aux=props[nprop][i].split()
 						valores.append(float(aux[0]))
 						if float(aux[0])>maxy: maxy=float(aux[0])
 						if float(aux[0])<miny: miny=float(aux[0])
-				
+
 					except:
 						valores.append('NA')
-		
+
 			if maxy==miny:
 				if maxy>0 :maxy=1.1*maxy
 				else: maxy=0.9
 				if miny>0 : miny=0.9*miny
 				else: miny=1.1*miny
-			
+
 			nat=nat_fin-nat_ini
 			sclx=(fx-ox)/nat
-		
+
 			scly=(oy-fy)/(maxy-miny)
-			
-				
+
+
 			dptos=[]
 			gc.set_foreground(tinta)
 			gc.line_width=3
 			for i in range(len(valores)):
 				try:
 					axe=(ox+i*sclx,oy-(valores[i]-miny)*scly)
-				
+
 				except:
 					axe=(ox+i*sclx,'NA')
-					
+
 				dptos.append(axe)
-		
+
 			ctd0=False
 			vale0=True
 			vale1=True
@@ -796,7 +964,7 @@ class GraficProps(MainWindow):
 				y0=int(y0)
 			except:
 				vale0=False
-			
+
 			while i<len(valores):
 				x1,y1=dptos[i]
 				try:
@@ -805,44 +973,44 @@ class GraficProps(MainWindow):
 				except:
 					vale1=False
 				if vale0 and vale1:
-				
+
 					pixmap.draw_line(gc,x0,y0,x1,y1)
 					ctd0=True
 				elif vale0 and not vale1 and not ctd0:
-				
+
 					pixmap.draw_rectangle(gc,True,x0-3,y0-3,6,6)
 				elif not vale0 and vale1: ctd0=False
-				
+
 
 				vale0=vale1
 				x0,y0=x1,y1
 				i+=1
 			if not vale0 and vale1:
-			
+
 				pixmap.draw_rectangle(gc,True,x1-3,y1-3,6,6)
-			
-				
+
+
 			if nat>10: numm=10
 			else: numm=nat
 			y0=oy+10
 			y1=oy-10
 			gc.set_foreground(gris)
 			gc.line_width=1
-		
+
 			pixmap.draw_line(gc, ox,oy,fx,oy)
-		
+
 			pixmap.draw_line(gc, ox,oy,ox,fy)
 			gc.line_style=1
 			if corresp[nprop]>=0:
 				txto.set_text('['+units[corresp[nprop]]+']')
-			
+
 				pixmap.draw_layout(gc,10,10,txto)
 			for i in range(numm+1):
 				x=sclx*(i*nat/numm)+ox
 				txto.set_text(repr(int(nat_ini+i*nat/numm)))
-			
+
 				pixmap.draw_line(gc,x,oy,x,fy)
-			
+
 				pixmap.draw_layout(gc,x-10, oy+10, txto)
 			inc=(maxy-miny)/10
 			x0=ox-10
@@ -852,27 +1020,50 @@ class GraficProps(MainWindow):
 				aux=inc*i+miny
 				axe="%.2e" % aux
 				txto.set_text(axe)
-			
+
 				pixmap.draw_line(gc,ox,y,fx,y)
-			
-				pixmap.draw_layout(gc,x0-90,y-15,txto)
+				if distro == 'fremantle':
+					pixmap.draw_layout(gc,x0-120,y-15,txto)
+				else:
+					pixmap.draw_layout(gc,x0-90,y-15,txto)
 
 			#pintar el pixmap
 			x , y, width, height = wgraf.get_allocation()
 			dra1.window.draw_drawable(dra1.get_style().fg_gc[gtk.STATE_NORMAL],pixmap, x, y, x, y, width, height)
-			
+
 			pass
-		
-		wgraf = hildon.Window()
+
+		def create_selector(titulo, graficable):
+			selector = hildon.hildon_touch_selector_new_text()
+			for i in range(len(titulo)):
+				if graficable[i]:
+					selector.append_text(titulo[i])
+
+			return selector
+
+		def create_bselector(sim):
+			selector = hildon.hildon_touch_selector_new_text()
+			for i in range(1,len(sim)):
+				selector.append_text(sim[i])
+
+			return selector
+
+		if distro == 'fremantle':
+			wgraf = hildon.StackableWindow()
+		else:
+			wgraf = hildon.Window()
+
 		wgraf.connect('destroy', gtk.Widget.destroy)
 		wgraf.set_title('Graphics')
 
-		
 		vbox1=gtk.VBox(False,3)
-	
+
 		dra1=gtk.DrawingArea()
 		dra1.show()
-		dra1.set_size_request(650,350)
+		if distro == 'fremantle':
+			dra1.set_size_request(800,350)
+		else:
+			dra1.set_size_request(650,350)
 
 		dra1.connect('expose_event',refoco)
 
@@ -891,82 +1082,113 @@ class GraficProps(MainWindow):
 		vbox1.pack_start(dra1, True, True,0)
 		hbox1=gtk.HBox(False,0)
 
-		comboprop=gtk.combo_box_new_text()
-		comboprop.set_size_request(230,30)
-		for i in range(len(titulo)):
-			if graficable[i]:
-				comboprop.append_text(titulo[i])
-		comboprop.set_active(0)
-		comboprop.show()
-		hbox1.pack_start(comboprop, True, True,0)
+		if distro == 'fremantle':
+			abutton = hildon.PickerButton(hildon.SIZE_REQUEST_MINIMUM, hildon.BUTTON_ARRANGEMENT_HORIZONTAL)
+			selector = create_selector(titulo, graficable)
+			abutton.set_selector(selector)
+			abutton.set_value('Atomic Weight')
+
+			bbutton = hildon.PickerButton(hildon.SIZE_REQUEST_MINIMUM, hildon.BUTTON_ARRANGEMENT_HORIZONTAL)
+			bselector = create_bselector(sim)
+			bbutton.set_selector(bselector)
+			bbutton.set_value('H')
+
+			cbutton = hildon.PickerButton(hildon.SIZE_REQUEST_MINIMUM, hildon.BUTTON_ARRANGEMENT_HORIZONTAL)
+			cselector = create_bselector(sim)
+			cbutton.set_selector(cselector)
+			cbutton.set_value('Rg')
+		else:
+			comboprop=gtk.combo_box_new_text()
+			comboprop.set_size_request(230,30)
+			for i in range(len(titulo)):
+				if graficable[i]:
+					comboprop.append_text(titulo[i])
+			comboprop.set_active(0)
+			comboprop.show()
+
+			combode=gtk.combo_box_new_text()
+			combode.set_size_request(80,30)
+			for i in range(1,len(sim)):
+				combode.append_text(sim[i])
+			combode.set_active(0)
+			combode.show()
+
+			comboa=gtk.combo_box_new_text()
+			comboa.set_size_request(80,30)
+			for i in range(1,len(sim)):
+				comboa.append_text(sim[i])
+			comboa.set_active(len(sim)-2)
+			comboa.show()
+
 		label1=gtk.Label("From:")
 		label1.set_size_request(80,30)
 		label1.show()
-		hbox1.pack_start(label1,True,True,0)
-		combode=gtk.combo_box_new_text()
-		combode.set_size_request(80,30)
-		for i in range(1,len(sim)):
-			combode.append_text(sim[i])
-		combode.set_active(0)
-		combode.show()
-		hbox1.pack_start(combode,True,True,0)
+
 		label2=gtk.Label("To:")
 		label2.set_size_request(45,30)
 		label2.show()
-		hbox1.pack_start(label2,False,False,0)
-		comboa=gtk.combo_box_new_text()
-		comboa.set_size_request(80,30)
-		for i in range(1,len(sim)):
-			comboa.append_text(sim[i])
-		comboa.set_active(len(sim)-2)
-		comboa.show()
-		hbox1.pack_start(comboa,True,True,0)
+
+		if distro == 'fremantle':
+			hbox1.pack_start(abutton, True, True,0)
+			hbox1.pack_start(label1,True,True,0)
+			hbox1.pack_start(bbutton,True,True,0)
+			hbox1.pack_start(label2,False,False,0)
+			hbox1.pack_start(cbutton,True,True,0)
+		else:
+			hbox1.pack_start(comboprop, True, True,0)
+			hbox1.pack_start(label1,True,True,0)
+			hbox1.pack_start(combode,True,True,0)
+			hbox1.pack_start(label2,False,False,0)
+			hbox1.pack_start(comboa,True,True,0)
+
 		boton=gtk.Button(label="Draw")
 		boton.set_size_request(80,40)
 		boton.show()
 		boton.connect("clicked", on_dibujar_clicked)
 		hbox1.pack_start(boton,True,True,0)
 		#boton salir
-		salir=gtk.Button(label="Close")
-	
-		salir.show()
-		salir.connect("clicked", lambda a: wgraf.destroy())
-		hbox1.pack_start(salir,True,True,0)
+		if distro != 'fremantle':
+			salir=gtk.Button(label="Close")
+			salir.show()
+			salir.connect("clicked", lambda a: wgraf.destroy())
+			hbox1.pack_start(salir,True,True,0)
+
 
-		
 		vbox1.pack_start(hbox1,True,True,0)
 		wgraf.add(vbox1)
 		wgraf.show_all()
-		
+
 		txto=dra1.create_pango_layout("")
 		dibujo=dra1.window
 		dibujo.show()
 		gc=dibujo.new_gc()
-		
+
 		pixmap=crea_pixmap(dra1)
-				
+
 		colormap=gc.get_colormap()
 		blanco=colormap.alloc_color('white')
 		negro=colormap.alloc_color('black')
 		tinta=colormap.alloc_color('brown')
 		gris=colormap.alloc_color('grey')
-		dra1.show()	
+		dra1.show()
 
 
 class Opciones(MainWindow):
 	def __init__(MainWindow):
-		
+
 		def on_cerrar_clicked(widget):
 			dlg.destroy()
 		def on_aceptar_clicked(widget):
 			global tref
 			tref=escala.get_value()
 			dlg.destroy()
-			
+
 
 		dlg = gtk.Dialog(title='Options', parent=None, flags=gtk.DIALOG_MODAL | gtk.WIN_POS_CENTER)
 		dlg.set_border_width(6)
-		dlg.set_default_size(560, 200)
+
+		if distro != 'fremantle':
+			dlg.set_default_size(560, 200)
 
 		hbox1 = gtk.HBox(False, 8)
 		hbox1.set_border_width(4)
@@ -988,35 +1210,54 @@ class Opciones(MainWindow):
 		hbuttonbox1.set_layout(gtk.BUTTONBOX_END)
 
 		button1 = gtk.Button(label="Set")
+		button1.set_size_request(70, 70)
 		button1.show()
 		button1.connect("clicked", on_aceptar_clicked)
 		hbuttonbox1.pack_start(button1)
 
-		button2 = gtk.Button(label="Cancel")
-		button2.show()
-		button2.connect("clicked", on_cerrar_clicked)
-		hbuttonbox1.pack_start(button2)
+		if distro != 'fremantle':
+			button2 = gtk.Button(label="Cancel")
+			button2.show()
+			button2.connect("clicked", on_cerrar_clicked)
+			hbuttonbox1.pack_start(button2)
 
 		dlg.action_area.pack_start(hbuttonbox1, False, False, 8)
 		dlg.vbox.pack_start(hbox1, True, True, 8)
-		
+
 		dlg.show_all()
 
 
 class WebConect(MainWindow):
 
 	def __init__(MainWindow):
+		def create_selector():
+			selector = hildon.hildon_touch_selector_new_text()
+			selector.append_text('http://webbook.nist.gov/chemistry/')
+			selector.append_text('http://www.iupac.org/')
+			selector.append_text('http://www.sciencedirect.com/')
+			selector.append_text('http://www.chemspider.com/')
+			selector.append_text('http://www.chemicool.com/')
+			selector.append_text('http://nobelprize.org/nobel_prizes/chemistry/')
+			selector.append_text('http://www.chemexper.com/')
+			selector.append_text('http://acswebcontent.acs.org/home.html')
+			selector.append_text('http://www.chemicalforums.com/')
+
+			return selector
+
 		def on_cerrar_clicked(widget):
 			dlg.destroy()
 		def on_aceptar_clicked(widget):
-			entrada=combo.child.get_text()
+			if distro == 'fremantle':
+				entrada = abutton.get_value()
+			else:
+				entrada=combo.child.get_text()
+
 			orden=comando+"\'"+entrada+"\'"
 			os.system(orden)
 			dlg.destroy()
 
-
 		comando="dbus-send --print-reply --dest=com.nokia.osso_browser /com/nokia/osso_browser/service com.nokia.osso_browser.load_url string:"
-	
+
 		dlg = gtk.Dialog(title='Web Connect...', parent=None, flags=gtk.DIALOG_MODAL | gtk.WIN_POS_CENTER)
 		dlg.set_border_width(6)
 		dlg.set_default_size(560, 200)
@@ -1025,11 +1266,25 @@ class WebConect(MainWindow):
 		hbox1.set_border_width(4)
 		label1 = gtk.Label("URL :  ")
 		hbox1.pack_start(label1, True, True, 0)
-		combo=gtk.combo_box_entry_new_text()
-		combo.append_text('webbook.nist.gov/chemistry/')
-		combo.append_text('http://www.iupac.org/')
 
-		hbox1.pack_start(combo, True, True, 0)
+		if distro == 'fremantle':
+			abutton = hildon.PickerButton(hildon.SIZE_REQUEST_MINIMUM, hildon.BUTTON_ARRANGEMENT_HORIZONTAL)
+			selector = create_selector()
+			abutton.set_selector(selector)
+			abutton.set_value('http://webbook.nist.gov/chemistry/')
+			hbox1.pack_start(abutton, True, True, 0)
+		else:
+			combo=gtk.combo_box_entry_new_text()
+			combo.append_text('http://webbook.nist.gov/chemistry/')
+			combo.append_text('http://www.iupac.org/')
+			combo.append_text('http://www.sciencedirect.com/')
+			combo.append_text('http://www.chemspider.com/')
+			combo.append_text('http://www.chemicool.com/')
+			combo.append_text('http://nobelprize.org/nobel_prizes/chemistry/')
+			combo.append_text('http://www.chemexper.com/')
+			combo.append_text('http://acswebcontent.acs.org/home.html')
+			combo.append_text('http://www.chemicalforums.com/')
+			hbox1.pack_start(combo, True, True, 0)
 
 
 		hbuttonbox1 = gtk.HButtonBox()
@@ -1039,18 +1294,20 @@ class WebConect(MainWindow):
 		hbuttonbox1.set_layout(gtk.BUTTONBOX_END)
 
 		button1 = gtk.Button(label="Go")
+		button1.set_size_request(70, 70)
 		button1.show()
 		button1.connect("clicked", on_aceptar_clicked)
 		hbuttonbox1.pack_start(button1)
 
-		button2 = gtk.Button(label="Close")
-		button2.show()
-		button2.connect("clicked", on_cerrar_clicked)
-		hbuttonbox1.pack_start(button2)
+		if distro != 'fremantle':
+			button2 = gtk.Button(label="Close")
+			button2.show()
+			button2.connect("clicked", on_cerrar_clicked)
+			hbuttonbox1.pack_start(button2)
 
 		dlg.action_area.pack_start(hbuttonbox1, False, False, 8)
 		dlg.vbox.pack_start(hbox1, True, True, 8)
-		
+
 		dlg.show_all()
 
 class WebQuery(MainWindow):
@@ -1067,24 +1324,34 @@ class WebQuery(MainWindow):
 				entrada='webbook.nist.gov/cgi/cbook.cgi?Name='+entrada
 			orden=comando+"\'"+entrada+"\'"
 			os.system(orden)
-			
+
 			dlg.destroy()
 
 
-		
 		comando="dbus-send --print-reply --dest=com.nokia.osso_browser /com/nokia/osso_browser/service com.nokia.osso_browser.load_url string:"
-	
+
 		dlg = gtk.Dialog(title='Query NIST database', parent=None, flags=gtk.DIALOG_MODAL | gtk.WIN_POS_CENTER)
 		dlg.set_border_width(6)
 		dlg.set_default_size(560, 200)
 
 		vbox1=gtk.VBox(False,8)
 		vbox1.set_border_width(4)
-		radio=gtk.RadioButton(None,"Name")
-		vbox1.pack_start(radio,True,True,0)
-		radio.set_active(True)
-		radio.show()
-		radio=gtk.RadioButton(radio,"Formula")
+		if distro == 'fremantle':
+			radio1 = hildon.GtkRadioButton(gtk.HILDON_SIZE_FINGER_HEIGHT)
+			radio1.set_mode(False)
+			radio1.set_label("Name")
+		else:
+			radio1=gtk.RadioButton(None,"Name")
+		vbox1.pack_start(radio1,True,True,0)
+		radio1.set_active(True)
+		radio1.show()
+		if distro == 'fremantle':
+			radio = hildon.GtkRadioButton(gtk.HILDON_SIZE_FINGER_HEIGHT)
+			radio.set_mode(False)
+			radio.set_label("Formula")
+			radio.set_group(radio1)
+		else:
+			radio=gtk.RadioButton(radio,"Formula")
 		vbox1.pack_start(radio,True,True,0)
 		radio.show()
 
@@ -1092,11 +1359,10 @@ class WebQuery(MainWindow):
 		hbox1.set_border_width(4)
 		label1 = gtk.Label("Key :  ")
 		hbox1.pack_start(label1, False, False, 1)
-		texto=gtk.Entry()
-		texto.set_text("")
-		texto.set_editable(True)
-		texto.set_visibility(True)
-		
+		if distro == 'fremantle':
+			texto=hildon.Entry(gtk.HILDON_SIZE_FINGER_HEIGHT)
+		else:
+			texto=gtk.Entry()
 
 		hbox1.pack_start(texto, True, True, 0)
 		hbox1.show()
@@ -1110,18 +1376,20 @@ class WebQuery(MainWindow):
 		hbuttonbox1.set_layout(gtk.BUTTONBOX_END)
 
 		button1 = gtk.Button(label="Query")
+		button1.set_size_request(70, 70)
 		button1.show()
 		button1.connect("clicked", on_aceptar_clicked)
 		hbuttonbox1.pack_start(button1)
 
-		button2 = gtk.Button(label="Close")
-		button2.show()
-		button2.connect("clicked", on_cerrar_clicked)
-		hbuttonbox1.pack_start(button2)
+		if distro != 'fremantle':
+			button2 = gtk.Button(label="Close")
+			button2.show()
+			button2.connect("clicked", on_cerrar_clicked)
+			hbuttonbox1.pack_start(button2)
 
 		dlg.action_area.pack_start(hbuttonbox1, False, False, 8)
 		dlg.vbox.pack_start(vbox1, True, True, 8)
-		
+
 		dlg.show_all()
 
 class AboutRefs(MainWindow):
@@ -1139,7 +1407,7 @@ class AboutRefs(MainWindow):
 
 		textview1 = gtk.TextView()
 		textview1.connect("event-after", self.event_after)
-		
+
 		textview1.set_wrap_mode(gtk.WRAP_NONE)
 		textview1.set_cursor_visible(False)
 		textview1.set_editable(False)
@@ -1151,20 +1419,22 @@ class AboutRefs(MainWindow):
 
 		self.hbox1.pack_start(textview1, True, True, 0)
 
-		hbuttonbox1 = gtk.HButtonBox()
-		hbuttonbox1.show()
-		hbuttonbox1.set_spacing(2)
-		hbuttonbox1.set_border_width(2)
-		hbuttonbox1.set_layout(gtk.BUTTONBOX_END)
 
-		button1 = gtk.Button(label="Close", stock=gtk.STOCK_CLOSE)
-		button1.show()
-		button1.connect("clicked", on_cerrar_clicked)
-		hbuttonbox1.pack_start(button1)
+		if distro != 'fremantle':
+			hbuttonbox1 = gtk.HButtonBox()
+			hbuttonbox1.show()
+			hbuttonbox1.set_spacing(2)
+			hbuttonbox1.set_border_width(2)
+			hbuttonbox1.set_layout(gtk.BUTTONBOX_END)
 
-		self.dlg.action_area.pack_start(hbuttonbox1, False, False, 8)
+			button1 = gtk.Button(label="Close", stock=gtk.STOCK_CLOSE)
+			button1.show()
+			button1.connect("clicked", on_cerrar_clicked)
+			hbuttonbox1.pack_start(button1)
+
+			self.dlg.action_area.pack_start(hbuttonbox1, False, False, 8)
 		self.dlg.vbox.pack_start(self.hbox1, True, True, 8)
-		
+
 		self.dlg.show_all()
 
 
